Module alsa

Module alsa 

Available on crate feature alsa only.
An idiomatic Rust ALSA interface.

Structs

AccessMask
Access mask used in combination with hardware parameters.
AsyncWriterpoll-driver
An interleaved type-checked async PCM writer.
CString
A string allocated through libc.
Card
A reference to a card.
Config
The stream configuration used after the configurator has been successfully installed.
Configurator
A simple Pcm stream configuration.
FormatMask
Format mask used in combination with hardware parameters.
HardwareParameters
Collection of current hardware parameters being configured for a Pcm handle.
HardwareParametersMut
Collection of harward parameters being configured for a Pcm handle.
Pcm
An opened PCM device.
SoftwareParameters
Collection of software parameters being configured for a Pcm handle.
SoftwareParametersMut
Collection of mutable software parameters being configured for a Pcm handle.
Writer
A interleaved type-checked PCM writer.

Enums

Access
Defines how the underlying device is accessed.
Direction
The direction in which updated hardware parameters is restricted unless the exact value is available.
Error
Errors that can be raised by the ALSA layer.
Format
Defines the supported format of a stream.
State
The state of the Pcm.
Stream
Defines the direction of a stream.
Timestamp
Defines if timestamps are enabled or not.
TimestampType
Defines the type of timestamp that is available.

Traits

Sample
Trait used to designate types which are sample-appropriate for Pcm.

Functions

cards
Construct an iterator over sounds cards.

Type Aliases

Result
Helper result wrapper.