pub enum Error {
Sys(Errno),
Io(Error),
FormatMismatch {
ty: &'static str,
format: Format,
},
ChannelsMismatch {
actual: usize,
expected: usize,
},
BadFormat(c_int),
BadAccess(c_uint),
BadTimestamp(c_uint),
BadTimestampType(c_uint),
MissingPollFds,
}Available on crate feature
alsa only.Expand description
Errors that can be raised by the ALSA layer.
Variants
Sys(Errno)
System error.
Io(Error)
I/O error.
FormatMismatch
Error raised when there’s a format mismatch between an underlying stream and the type attempting to be used with it.
Fields
ChannelsMismatch
Error raised when there’s a channel count mismatch between an underlying stream and the type attempting to be used with it.
BadFormat(c_int)
Underlying function call returned an illegal format identifier.
BadAccess(c_uint)
Underlying function call returned an illegal access identifier.
BadTimestamp(c_uint)
Underlying function call returned an illegal timestamp identifier.
BadTimestampType(c_uint)
Underlying function call returned an illegal timestamp type identifier.
MissingPollFds
Underlying PCM was not set up for polling.