Module runtime

Module runtime 

If any available, this provides handles for various forms of asynchronous drivers that can be used in combination with audio interfaces.

Structs

Runtime
The audio runtime.
RuntimeGuard
The runtime guard constructed with Runtime::enter.