pub struct InitializedClient<T, E> { /* private fields */ }Available on crate feature
wasapi only.Expand description
A client that has been initialized with the given type T.
The type must implement the Sample trait to make sure it’s appropriate for use with WASAPI.
Implementations
Sourceimpl<T, E> InitializedClient<T, E>where
T: Sample,
impl<T, E> InitializedClient<T, E>where
T: Sample,
Sourcepub fn config(&self) -> ClientConfig
pub fn config(&self) -> ClientConfig
Get the initialized client configuration.
Sourcepub fn render_client(&self) -> Result<RenderClient<T, E>, Error>
pub fn render_client(&self) -> Result<RenderClient<T, E>, Error>
Construct a render client used for writing output into.