If any available, this provides handles for various forms of asynchronous drivers that can be used in combination with audio interfaces.
Structs
- Runtime
- The audio runtime.
- Runtime
Guard - The runtime guard constructed with Runtime::enter.